<template>
  <!-- 安全隐患排查记录添加 -->
  <el-dialog :close-on-click-modal="false" :title="'修改安全检查记录'" :visible.sync="showDetaileList" width="45%"
    :before-close="handelCloseDetail" top="8vh">
    <el-form ref="detailFormInfo" :rules="rulesDetail" :model="detailListFrom" label-width="140px">
      <el-row>
        <el-col :span="24">
          <el-form-item label="隐患排查发现时间" prop="checkDate">
            <el-date-picker v-model="detailListFrom.checkDate" size="small" type="date" value-format="yyyy-MM-dd"
              placeholder="请选择隐患排查发现时间" style="width:100%" />
          </el-form-item>
        </el-col>
        <el-col :span="24">
          <el-form-item label="隐患内容" prop="dangerContent">
            <el-input style="width:100%" v-model="detailListFrom.dangerContent" placeholder="请输入隐患内容"></el-input>
          </el-form-item>
        </el-col>
        <el-col :span="24">
          <el-form-item label="整改措施建议" prop="reformSugguest" placeholder="请输入整改措施建议">
            <el-input style="width:100%" v-model="detailListFrom.reformSugguest"></el-input>
          </el-form-item>
        </el-col>
        <el-col :span="24">
          <el-form-item label="参考依据说明" placeholder="请输入参考依据说明" prop="reference">
            <el-input style="width:100%" v-model="detailListFrom.reference"></el-input>
          </el-form-item>
        </el-col>
      </el-row>
      <el-row>
        <el-col :span="24">
          <el-form-item label="隐患图片" prop="unitAddress">
            <el-upload name="files" :action="uploadUrl" :headers="header" accept="image/jpg, image/jpeg, image/png"
              :data="{ bizCode: 'Image', bizId: '' }" :on-success="(response, file, fileList) => {
                return handleAvatarSuccess(
                  response,
                  file,
                  fileList
                )
              }
                " :before-upload="beforeAvatarUpload" list-type="picture-card" :on-remove="(file, fileList) => {
                  return handleRemove(file, fileList)
                }
                  " :file-list="convertImg(detailListFrom.imgUrlArray)">
              <i slot="default" class="el-icon-plus" />
            </el-upload>
          </el-form-item>
        </el-col>
        <el-col :span="24">
          <el-form-item label="整改状态" placeholder="请选择整改状态" prop="reformStatus">
            <template>
              <el-radio v-model="detailListFrom.reformStatus" :label="2">未完成</el-radio>
              <el-radio v-model="detailListFrom.reformStatus" :label="3">已完成</el-radio>
            </template>
          </el-form-item>
        </el-col>
        <el-col :span="24">
          <el-form-item label="整改后图片" prop="unitUsername">
            <el-upload name="files" :action="uploadUrl" :headers="header" accept="image/jpg, image/jpeg, image/png"
              :data="{ bizCode: 'Image', bizId: '' }" :on-success="(response, file, fileList) => {
                return handleAvatarSuccess1(
                  response,
                  file,
                  fileList,
                )
              }
                " :before-upload="beforeAvatarUpload" list-type="picture-card" :on-remove="(file, fileList) => {
                  return handleRemove1(file, fileList)
                }
                  " :file-list="convertImg(detailListFrom.reformImgUrlArray)">
              <i slot="default" class="el-icon-plus" />
            </el-upload>
          </el-form-item>
        </el-col>
        <el-col :span="24">
          <el-form-item label="整改描述">
            <el-input type="textarea" :autosize="{ minRows: 2, maxRows: 4 }" style="width:100%"
              v-model="detailListFrom.reformContent" placeholder="请输入整改描述"></el-input>
          </el-form-item>
        </el-col>
      </el-row>
    </el-form>
    <span slot="footer" class="dialog-footer">
      <el-button type="primary" @click="handleSaveDetailList">保 存</el-button>
      <el-button @click="handelCloseDetail">取 消</el-button>
    </span>
  </el-dialog>
</template>

<script>
import CmgtSaftyDangerCheckrecordApi from '@/views/Manage/saftyDanger/api/CmgtSaftyDangerCheckrecordApi'
import { mapState } from 'vuex'

export default {
  name: 'CmgtSaftyDangerCheckrecordFormDialog',
  components: {},
  data() {
    return {
      showDetaileList: false,
      previewUrl:
        window.context.portal +
        '/file/onlinePreviewController/v1/getFileById_',
      uploadUrl: window.context.portal + '/file/v1/fileUpload', // 服务器上传地址
      params: {},
      detailListFrom: {
        checkRecordId: null,
        unitId: null,
        reformImgUrlArray: [],
        imgUrlArray: [],
        checkDate: null,
        dangerContent: null,
        reformContent: null,
        reformStatus: 2,
        reformSugguest: null,
        reference: null,
        id: null
      },
      rulesDetail: {
        checkDate: [
          {
            required: true,
            message: '隐患排查发现时间不能为空',
            trigger: 'blur'
          }
        ],
        dangerContent: [
          {
            required: true,
            message: '隐患内容不能为空',
            trigger: 'blur'
          }
        ],
        reformStatus: [
          {
            required: true,
            message: '请选择整改状态',
            trigger: 'change'
          }
        ],
      }
    }
  },
  created() {
  },
  computed: mapState({
    header: state => {
      return {
        Authorization: `Bearer ${state.login.currentUser.token}`
      }
    }
  }),
  methods: {
    showInfo(row) {
      CmgtSaftyDangerCheckrecordApi.CSaftyDangerCheckrecordDetailById(
        row.id,
        res => {
          this.detailListFrom.checkRecordId = res.checkRecordId
          this.detailListFrom.unitId = res.unitId
          this.detailListFrom.imgUrlArray = res.imgUrlArray
            ? res.imgUrlArray
            : []
          this.detailListFrom.reformImgUrlArray = res.reformImgUrlArray
            ? res.reformImgUrlArray
            : []
          this.detailListFrom.checkDate = res.checkDate
          this.detailListFrom.dangerContent = res.dangerContent
          this.detailListFrom.reformContent = res.reformContent
          this.detailListFrom.reformStatus = res.reformStatus
          this.detailListFrom.reformSugguest = res.reformSugguest
          this.detailListFrom.reference = res.reference
          this.detailListFrom.id = res.id
          this.showDetaileList = true
        }
      )
    },
    handleAvatarSuccess(res, file, fileList) {
      if (res.success) {
        let arr = []
        arr.push(res.fileId)
        this.detailListFrom.imgUrlArray = this.detailListFrom.imgUrlArray.concat(
          arr
        )
      } else {
        this.$message.error('上传文件失败！')
      }
    },
    handleAvatarSuccess1(res, file, fileList) {
      if (res.success) {
        let arr = []
        arr.push(res.fileId)
        this.detailListFrom.reformImgUrlArray = this.detailListFrom.reformImgUrlArray.concat(
          arr
        )
      } else {
        this.$message.error('上传文件失败！')
      }
    },
    beforeAvatarUpload(file) {
      console.log(file)
      const isJPG =
        file.type === 'image/jpeg' ||
        file.type === 'image/png' ||
        file.type === 'image/jpg'
      const isLt1M = file.size / 1024 / 1024 < 10
      if (!isJPG) {
        this.$message.error('上传图片只能是 JPG 格式!')
      }
      if (!isLt1M) {
        this.$message.error('上传图片大小不能超过 1MB!')
      }
      return isJPG && isLt1M
    },
    handleRemove(file, fileList) {
      this.detailListFrom.imgUrlArray.forEach((e, index) => {
        if (e == file.id) {
          this.detailListFrom.imgUrlArray.splice(index, 1)
        }
      })
    },
    handleRemove1(file, fileList) {
      this.detailListFrom.reformImgUrlArray.forEach((e, index) => {
        if (e == file.id) {
          this.detailListFrom.reformImgUrlArray.splice(index, 1)
        }
      })
    },
    // 图片转换
    convertImg(arr) {
      let newArr = []
      if (Array.isArray(arr)) {
        newArr = arr.map(it => {
          return { url: this.previewUrl + it, id: it }
        })
        return newArr
      }
    },
    handelCloseDetail() {
      this.detailListFrom = {
        checkRecordId: null,
        unitId: null,
        imgUrlArray: [],
        reformImgUrlArray: [],
        checkDate: null,
        dangerContent: null,
        reformContent: null,
        reformStatus: 2,
        reformSugguest: null,
        reference: null,
        id: null
      }
      this.$emit('refreshList')
      this.showDetaileList = false
    },
    // 检查明细保存
    handleSaveDetailList() {
      this.$refs.detailFormInfo.validate(valid => {
        if (valid) {
          CmgtSaftyDangerCheckrecordApi.CSaftyDangerCheckrecordDetailUpdateById(
            this.detailListFrom,
            res => {
              console.log(res)
              this.$notify({
                type: 'success',
                message: '修改成功',
                duration: 2000
              })
              this.handelCloseDetail()
            }
          )
        }
      })
    }
  }
}
</script>
<style lang="scss" scoped>
::deep .el-collapse-item__content {
  padding-bottom: 0px;
}

.step-container {
  width: 80%;
  margin: 0 auto 20px;
}

.dialog-footer {
  text-align: center;
}
</style>
<style lang="scss" scoped>
::v-deep .el-upload--picture-card {
  width: 75px !important;
  height: 75px !important;
  line-height: 90px !important;
}

::v-deep .el-upload-list--picture-card .el-upload-list__item {
  width: 75px !important;
  height: 75px !important;
}

::v-deep .el-upload-list__item {
  transition: none !important;
  -webkit-transition: none !important;
}

::v-deep .el-upload-list__item-name {
  transition: none !important;
  -webkit-transition: none !important;
}
</style>
